<?php
namespace Ep\Wp\Plugin\I18n;

use Ep\Cache\AbstractCacheFactory;
use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu TranslationCache plugina.
 *
 * @package Ep\Wp\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
class TranslationCacheFactory implements FactoryInterface
{
    /**
     * Stvara plugin.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TranslationCache
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $cacheFactory = new AbstractCacheFactory();

        $cache = $cacheFactory($container, '', [
            'adapter' => 'filesystem',
            'options' => [
                'namespace' => 'i18n',
                'default_lifetime' => 0,
            ],
        ]);

        return new TranslationCache($cache);
    }
}
